==> CXJ_MZ_CategorizeOptions-v1.2.zip: CategorizeOptions/js/plugins/CategorizeOptionsDebugger.js <==
(() => {
  window.CXJ_MZ = window.CXJ_MZ || {};
  const {
    CXJ_MZ
  } = window;

  const {
    CoreEssentials,
    CategorizeOptions,
  } = CXJ_MZ;

  const {
    addOption,
    addSpacer,
  } = CategorizeOptions;

  const backVisible = function(category) {
    return this.backVisible(category);
  }

  const selectProps = {
    type: 'select',
    category: 'debug',
    display: 'sbs',
    stretch: true,
    newLine: true,
    minimumRect: false,
  };

  const selectItems1 = [
    {
      name: 'Test 1',
      symbol: 'test1',
    },
    {
      name: 'Test 2',
      symbol: 'test2',
    },
  ]

  const selectItems2 = [
    ...selectItems1,
    {
      name: 'Test 3',
      symbol: 'test3',
    },
  ];

  const selectItems3 = [
    ...selectItems2,
    {
      name: 'Test 4',
      symbol: 'test4',
    },
    {
      name: 'Test 5',
      symbol: 'test5',
    },
    {
      name: 'Test 6',
      symbol: 'test6',
    },
    {
      name: 'Test 7',
      symbol: 'test7',
    },
    {
      name: 'Test 8',
      symbol: 'test8',
    },
  ];
  
  const selectItems4 = [
    {
      name: 'Long select option',
      symbol: 'option1',
    },
    {
      name: 'Another long select option',
      symbol: 'option2',
    },
    {
      name: 'An even longer select option',
      symbol: 'option3',
    },
    {
      name: 'An especially long select option label that is too long',
      symbol: 'option4',
    },
    {
      name: 'A short option',
      symbol: 'option5',
    },
    {
      name: 'Short option',
      symbol: 'option6',
    },
  ];

  addOption('Debug', 'debug', { type: 'category', insertBefore: 'reset' });

  addOption('Boolean 1', 'boolean-1', { type: 'boolean', category: 'debug', display: 'sbs', minimizeRect: false });
  addOption('Boolean 2', 'boolean-2', { type: 'boolean', category: 'debug', display: 'toggle', minimizeRect: false });
  addOption('Boolean 3', 'boolean-3', { type: 'boolean', category: 'debug', display: 'sbs', minimizeRect: true });
  addOption('Boolean 4', 'boolean-4', { type: 'boolean', category: 'debug', display: 'toggle', minimizeRect: true });

  addSpacer('debug');

  addOption('Option type: Select', 'label-1', { type: 'label', category: 'debug', textColor: 14 });

  addOption('Select 1', 'select-1', { ...selectProps, options: selectItems2 });
  addOption('Select 2', 'select-2', { ...selectProps, options: selectItems2, stretch: false });
  addOption('Select 3', 'select-3', { ...selectProps, options: selectItems3 });
  addOption('Select 4', 'select-4', { ...selectProps, options: selectItems3, newLine: false, display: 'toggle' });
  addOption('Select 5', 'select-5', { ...selectProps, options: selectItems3, display: 'toggle' });
  addOption('Select 6', 'select-6', { ...selectProps, options: selectItems3, display: 'toggle', minimizeRect: true });
  addOption('Select 7', 'select-7', { ...selectProps, options: selectItems3, minimizeRect: true });
  addOption('Select 8', 'select-8', { ...selectProps, options: selectItems3, newLine: false, display: 'toggle', minimizeRect: true });
  addOption('Select 9', 'select-9', { ...selectProps, options: selectItems1, newLine: false, minimizeRect: true });
  addOption('Select 10', 'select-10', { ...selectProps, options: selectItems4, minimizeRect: true });

  addSpacer('debug');

  addOption('Back', 'cancel', { type: 'cancel', category: 'debug', visible: backVisible });

})();

==> CXJ_MZ_CategorizeOptions-v1.4.1.zip: CategorizeOptions/js/plugins/CategorizeOptionsDebugger.js <==
(() => {
  window.CXJ_MZ = window.CXJ_MZ || {};
  const {
    CXJ_MZ
  } = window;

  const {
    CoreEssentials,
    CategorizeOptions,
  } = CXJ_MZ;

  const {
    addOption,
    addSpacer,
  } = CategorizeOptions;

  const backVisible = function(category) {
    return this.backVisible(category);
  }

  const selectProps = {
    type: 'select',
    category: 'debug',
    display: 'sbs',
    stretch: true,
    newLine: true,
    minimumRect: false,
  };

  const selectItems1 = [
    {
      name: 'Test 1',
      symbol: 'test1',
    },
    {
      name: 'Test 2',
      symbol: 'test2',
    },
  ]

  const selectItems2 = [
    ...selectItems1,
    {
      name: 'Test 3',
      symbol: 'test3',
    },
  ];

  const selectItems3 = [
    ...selectItems2,
    {
      name: 'Test 4',
      symbol: 'test4',
    },
    {
      name: 'Test 5',
      symbol: 'test5',
    },
    {
      name: 'Test 6',
      symbol: 'test6',
    },
  ];

  addOption('Debug', 'debug', { type: 'category', insertBefore: 'endFiller' });

  addOption('Boolean 1', 'boolean-1', { type: 'boolean', category: 'debug', display: 'sbs', minimizeRect: false });
  addOption('Boolean 2', 'boolean-2', { type: 'boolean', category: 'debug', display: 'toggle', minimizeRect: false });
  addOption('Boolean 3', 'boolean-3', { type: 'boolean', category: 'debug', display: 'sbs', minimizeRect: true });
  addOption('Boolean 4', 'boolean-4', { type: 'boolean', category: 'debug', display: 'toggle', minimizeRect: true });

  addSpacer('debug');

  addOption('Option type: Select', 'label-1', { type: 'label', category: 'debug', textColor: 14 });

  addOption('Select 1', 'select-1', { ...selectProps, options: selectItems2 });
  addOption('Select 2', 'select-2', { ...selectProps, options: selectItems2, stretch: false });
  addOption('Select 3', 'select-3', { ...selectProps, options: selectItems3 });
  addOption('Select 4', 'select-4', { ...selectProps, options: selectItems3, newLine: false, display: 'toggle' });
  addOption('Select 5', 'select-5', { ...selectProps, options: selectItems3, display: 'toggle' });
  addOption('Select 6', 'select-6', { ...selectProps, options: selectItems3, display: 'toggle', minimizeRect: true });
  addOption('Select 7', 'select-7', { ...selectProps, options: selectItems3, minimizeRect: true });
  addOption('Select 8', 'select-8', { ...selectProps, options: selectItems3, newLine: false, display: 'toggle', minimizeRect: true });
  addOption('Select 9', 'select-9', { ...selectProps, options: selectItems1, newLine: false, minimizeRect: true });

  addSpacer('debug');

  addOption('Back', 'cancel', { type: 'cancel', category: 'debug', visible: backVisible });

})();
